# django-cbv-htmx

This package helps connect Django Class-Based-Views with HTMX. These functions, tools, and mixins can be used without
HTMX as well, they were simply designed for converting a Django app into a slightly more progressive web-app using HTMX.
